@@ -9,6 +9,8 @@ function(x, ...)
     cat("\nCall:\n")
     print(x$call)
 
+    cat("\nused p=", x$p, sep="")
+    
     cat("\nMethods used:\n")
     um <- sort(unique(x$methods))
     for(u in um) {
@@ -16,6 +18,8 @@ function(x, ...)
       cat(sum(m), "\t", u, sep="")
       if(u != "complete" && u != "lsr") {
         r <- range(x$ncomp[m])
+        ncomp <- "ncomp"
+        if(u == "ridge") ncomp <- "lambda"
         cat(paste(", ncomp range: [", signif(r[1],5), ",", signif(r[2],5), "]", sep=""))
       }
       cat("\n")
